#!/bin/sh

# This script is used to initialize a new disk containing 
# only the first (root) partition from etc/rc. This script
# thus assume root partition is already mounted.
#
# The intended disk layout after executing this script 
# will be:
#	Partition 1: root fs
#	Partition 2: swap
#	Partition 3: user data mounted at /volume1
# 
# It (clear existing if any and re)create partition 2,3,4 
# on /dev/sda.
#
#
. /etc/rc.subr

echo "# DEBUG: Installer.sh begin..."

RaidTool="/sbin/raidtool"
PROCPARTITION="/proc/partitions"
SupportRAID=`/bin/get_key_value /etc/synoinfo.conf supportraid`
SupportDualhead=`/bin/get_key_value /etc.defaults/synoinfo.conf support_dual_head`
DefaultFS=`/bin/get_key_value /etc/synoinfo.conf defaultfs`
SystemFS=`/bin/get_key_value /etc/synoinfo.conf systemfs`
SupportBuildinStorage=`/bin/get_key_value /etc.defaults/synoinfo.conf support_buildin_storage`
UniqueRD=`/bin/get_key_value /etc.defaults/synoinfo.conf unique | cut -d"_" -f2`
EmmcBoot=`/bin/get_key_value /etc.defaults/synoinfo.conf support_emmc_boot`

DISKNODE="/dev/sda"
PARTNO_ROOT="1"
PARTNO_PATCH="2"
PARTNO_SWAP="3"
PARTNO_DATA="4"
# WARNING! Size in "Sectros", not in bytes! (512 bytes per sector by default)
WRITEABLE_SIZE=4194304
PATCH_SIZE=$WRITEABLE_SIZE
SWAP_SIZE=1048576
KERNEL_SIZE=32768
DATA_SIZE="-1"
ROOT_SKIP=0
DATA_SKIP=0
PATCH_SKIP=0
SWAP_SKIP=0
LINUX_FS_TYPE=83
LINUX_SWAP_TYPE=82

Sfdisk="/sbin/sfdisk"
Mount="/bin/mount"
Umount="/bin/umount"
FlagFile="/SynoRepart"
FS_Opt=""
ErrorFile="/tmp/installer.error"
HaveDisk=1

HAS_SYSTEM_PARTITION=0
DO_CLEAN_PARTITION="1"

###########################################################

# stop all burn-in test (memtester or DMA test) before install
/usr/sbin/burnin_test -f &> /dev/null

/bin/echo "Check new disk..."
for i
do
	case "${i}"
	in
		-n)
			DO_CLEAN_PARTITION="0"
			shift
		;;
		-s)
			HAS_SYSTEM_PARTITION=1
			shift
		;;		
	esac
done

/bin/rm ${ErrorFile}

/bin/dd if=/dev/sda of=/dev/null count=1 > /dev/null 2>&1
if [ $? != "0" ]; then
	IfErrorThenExit "NODISK" 1 ${ErrorFile}
fi

/bin/umount /volume1
/sbin/swapoff ${DISKNODE}${PARTNO_SWAP}

if [ "${DO_CLEAN_PARTITION}" = "1" ]; then
	# clean partitions
	for RaidVol in 0 1 2 3 4 5 6 7 8 9 10 11 12; do
		/bin/grep md${RaidVol} ${PROCPARTITION}
		if [ $? -eq 0 ]; then
			/bin/echo "${RaidTool} destroy ${RaidVol}"
			${RaidTool} destroy ${RaidVol}
		fi
	done

	if [ $HAS_SYSTEM_PARTITION -eq 1 ]; then
		# Clean Data and Patch partitions
		for Partition in 2 4; do
			/bin/echo "Clean partition ${Partition}"
			CleanPartition ${Partition} ${DISKNODE}
			IfErrorThenExit "CLEAN" $? ${ErrorFile}
		done

		Res=0
		# Notify Assistant to skip format system partition
		/bin/touch "/.skip_format_sys"
		/bin/echo "touching /.skip_format_sys"

	else
		# Doesn't has system/data partition, clean all partition
		${Sfdisk} -M1 ${DISKNODE}
		ResFdisk=$?
		IfErrorThenExit "FDISK" $ResFdisk ${ErrorFile}
		# WDMC has 8 partitions!
		for Partition in 1 2 3 4 5 6 7 8; do
			/bin/echo "Clean partition ${Partition}"
			CleanPartition ${Partition} ${DISKNODE}
			IfErrorThenExit "CLEAN" $? ${ErrorFile}
		done

		# WDMC: Default WD layout
		echo "# DEBUG: Creating new disk layout (except data/4 partition)"
		CreatePartition 1 ${WRITEABLE_SIZE} ${LINUX_FS_TYPE} ${ROOT_SKIP} ${DISKNODE}
		IfErrorThenExit "CREATE" $? ${ErrorFile}
		CreatePartition 2 ${WRITEABLE_SIZE} ${LINUX_FS_TYPE} ${ROOT_SKIP} ${DISKNODE}
		IfErrorThenExit "CREATE" $? ${ErrorFile}
		CreatePartition 3 ${SWAP_SIZE} ${LINUX_SWAP_TYPE} ${SWAP_SKIP} ${DISKNODE}
		IfErrorThenExit "CREATE" $? ${ErrorFile}
		CreatePartition 4 ${DATA_SIZE} ${LINUX_FS_TYPE} ${DATA_SKIP} ${DISKNODE}
		IfErrorThenExit "CREATE" $? ${ErrorFile}
		CreatePartition 5 ${KERNEL_SIZE} 0 0 ${DISKNODE}
		IfErrorThenExit "CREATE" $? ${ErrorFile}
		CreatePartition 6 ${KERNEL_SIZE} 0 0 ${DISKNODE}
		IfErrorThenExit "CREATE" $? ${ErrorFile}
		CreatePartition 7 2048 0 0 ${DISKNODE}
		IfErrorThenExit "CREATE" $? ${ErrorFile}
		CreatePartition 8 2048 0 0 ${DISKNODE}
		IfErrorThenExit "CREATE" $? ${ErrorFile}

		sleep 1
		# WDMC Fix - Add more partitions
		synodd ${DISKNODE}1 ${DISKNODE}2 ${DISKNODE}3 ${DISKNODE}5 ${DISKNODE}6 ${DISKNODE}7 ${DISKNODE}8
		IfErrorThenExit "SYNODD" $? ${ErrorFile}

		/bin/echo "mkswap ${DISKNODE}${PARTNO_SWAP}"
		/sbin/mkswap ${DISKNODE}${PARTNO_SWAP}
		IfErrorThenExit "MKSWAP" $? ${ErrorFile}

		FS_Opt=$( get_mkfs_option ${SystemFS} )
		/sbin/mkfs.${SystemFS} ${FS_Opt} ${DISKNODE}${PARTNO_ROOT}
		Res=$?
		IfErrorThenExit "MKFS" $Res ${ErrorFile}

		/sbin/mkfs.${DefaultFS} ${DISKNODE}${PARTNO_DATA}
		Res=$?
		IfErrorThenExit "MKFS" $Res ${ErrorFile}

		/sbin/mkfs.${SystemFS} ${DISKNODE}${PARTNO_PATCH}
		Res=$?
		IfErrorThenExit "MKFS" $Res ${ErrorFile}
	fi
fi

if [ $Res -eq 0 ]; then
	/bin/mount ${DISKNODE}${PARTNO_ROOT} /mnt
	/bin/touch /mnt/.noroot
	/bin/umount /mnt
fi

if [ -x /usr/syno/bin/mantool ]; then
	/usr/syno/bin/mantool -auto_poweron_disable
fi

/bin/echo "# DEBUG: Installer.sh done."

exit 0