#!/bin/sh

# This script is used to initialize a new disk containing 
# only the first (root) partition from etc/rc. This script
# thus assume root partition is already mounted.
#
# The intended disk layout after executing this script 
# will be:
#	Partition 1: root fs
#	Partition 2: swap
#	Partition 3: user data mounted at /volume1
# 
# It (clear existing if any and re)create partition 2,3,4 
# on /dev/sda.
#
#
. /etc.defaults/rc.subr

PROCPARTITION="/proc/partitions"
SupportRAID=`/bin/get_key_value /etc/synoinfo.conf supportraid`
DefaultFS=`/bin/get_key_value /etc/synoinfo.conf defaultfs`
SupportEBoxExpand=`/bin/get_key_value /etc.defaults/synoinfo.conf support_ebox_expand_vol`
EmmcBoot=`/bin/get_key_value /etc.defaults/synoinfo.conf support_emmc_boot`

DISKNODE="/dev/sda"
PARTNO_SWAP="3"
PARTNO_DATA="4"
DATA_SKIP=0
DATA_SIZE=-1
LINUX_FS_TYPE=83
LINUX_SWAP_TYPE=82

Sfdisk="/sbin/sfdisk"
Mount="/bin/mount"
Umount="/bin/umount"
FlagFile="/SynoRepart"
ErrorFile="/tmp/installer.error"
FS_Opt=""

# ##########################################################

RCMsg "Checking new disks ..."
if [ ! -e ${FlagFile} ]; then
	echo "No new disk. Do nothing."
	exit 0
#elif [ "yes" = "${EmmcBoot}" ]; then
#	echo "1/1" > /tmp/mkfs.progress.sda4
#	rm -rf ${FlagFile}
#	echo "Support eMMC boot. Do nothing."
#	exit 0
else
	echo "New disk. Begin initialization."
fi

rm ${ErrorFile}

# clean data volume
for Partition in 4; do
	# to save some seconds, clear that partition only if it really exists
	grep sda${Partition} ${PROCPARTITION}
	if [ $? -eq 0 ]; then
		echo "Clean partition ${Partition}"
		CleanPartition ${Partition} ${DISKNODE}
		IfErrorThenExit "CLEAN" $? ${ErrorFile}
	fi
done

# Create data partition
VOLUME_DEVICE=${DISKNODE}${PARTNO_DATA}
# create data partition - use all remaining space
CreatePartition ${PARTNO_DATA} ${DATA_SIZE} ${LINUX_FS_TYPE} ${DATA_SKIP} ${DISKNODE}
IfErrorThenExit "CREATE" $? ${ErrorFile}

swapon ${DISKNODE}${PARTNO_SWAP}
FS_Opt=$( get_mkfs_option ${DefaultFS} )
mkfs.${DefaultFS} ${FS_Opt} ${VOLUME_DEVICE}
Res=$?
IfErrorThenExit "MKFS" $Res ${ErrorFile}
swapoff ${DISKNODE}${PARTNO_SWAP}

# make a copy of configurations from default
#cp -R	/etc.defaults					/etc
#cp -R	/usr/syno/etc.defaults			/usr/syno/etc
#cp -R	/var.defaults					/var

if [ $Res -eq 0 ]; then
	rm -rf ${FlagFile}
fi